Storekit2Helper class

Constructors

Storekit2Helper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

buyProduct(String productId, void onResult(bool success, TransactionData? transaction, String? errorMessage), {String? uuid}) → Future<void>
fetchProducts(List<String> productIDs) → Future<List<ProductDetail>>
fetchPurchaseHistory() → Future<List<String>>
finishTransaction(int transactionId) → Future<bool>
hasActiveSubscription() → Future<bool>
initialize({TransactionHandler? unfinishedTransactionHandler}) → Future<void>
restorePurchases() → Future<List<TransactionData>>