TransactionData class

Constructors

TransactionData({String? transactionId, String? productId, String? transactionDate, String? originalTransactionId, String? status, String? json, String? appAccountToken, String? receiptData, String? jwsRepresentation})
TransactionData.fromMap(Map<String, dynamic> map)
factory

Properties

appAccountToken → String?
final
hashCode → int
The hash code for this object.
no setterinherited
json → String?
final
jwsRepresentation → String?
final
originalTransactionId → String?
final
productId → String?
final
receiptData → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
final
transactionDate → String?
final
transactionId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited